Learn R Programming

Carlson (version 3.0.0)

elliptic_E: Incomplete elliptic integral of the second kind

Description

Evaluate the incomplete elliptic integral of the second kind.

Usage

elliptic_E(phi, m, minerror = 1e-15)

Value

A complex number or vector, the value(s) of the incomplete elliptic integral E(φ,m).

Arguments

phi

amplitude, real or complex number/vector

m

parameter, real or complex number/vector

minerror

the bound on the relative error passed to Carlson_RF and Carlson_RD

Examples

Run this code
elliptic_E(1, 0.2)
gsl::ellint_E(1, sqrt(0.2))

Run the code above in your browser using DataLab