powered by
Evaluate the incomplete elliptic integral of the second kind.
elliptic_E(phi, m, minerror = 1e-15)
A complex number or vector, the value(s) of the incomplete elliptic integral E(φ,m).
amplitude, real or complex number/vector
parameter, real or complex number/vector
the bound on the relative error passed to Carlson_RF and Carlson_RD
Carlson_RF
Carlson_RD
elliptic_E(1, 0.2) gsl::ellint_E(1, sqrt(0.2))
Run the code above in your browser using DataLab